<?php
/**
 * This file responsible to all the setting and action on admin custom shortcode.
 *
 * @link       https://www.linkedin.com/in/arissetia/
 * @since      0.4.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 */

/**
 * Setup custom shortcode classes action.
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     M Aris Setiawan <https://www.linkedin.com/in/arissetia/>
 */
class Wanotif_Woocommerce_Admin_Custom_Shortcode {

	/**
	 * The ID of this plugin.
	 *
	 * @since    0.4.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    0.4.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;


	/**
	 * Initialize all required perform.
	 *
	 * @since 0.4.0
	 * @param string $plugin_name The name of this plugin.
	 * @param string $version The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Add menu shortcode
	 *
	 * @since 0.4.0
	 */
	public function register_the_menu() {
		$page_title = 'Custom Shortcode';
		$menu_title = 'wanotif ShortCode';
		$capability = 'manage_options';
		$menu_slug = $this->plugin_name . '_custom_shortcode';
		$function = array( $this, 'display_admin_page' );
		$icon_url = '';
		$position = null;

		add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );
	}

	/**
	 * Display the admin custom shortcode
	 *
	 * @since 0.4.0
	 */
	public function display_admin_page() {
		include_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'admin/partials/wanotif-woocommerce-admin-custom-shortcode.php';
	}

	/**
	 * Register the style and scripts.
	 *
	 * @since 0.4.0
	 * @param string $hook the url location of current admin page.
	 */
	public function register_script_style( $hook ) {
		if ( 'toplevel_page_wanotif-woocommerce_custom_shortcode' !== $hook ) {
			return;
		}
		wp_enqueue_style( $this->plugin_name . '-custom-shortcode-css', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/css/admin-custom-shortcode.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name . '-emoji-css', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/css/emoji.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name . '-font-aws-css', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css', array(), $this->version, 'all' );

		wp_enqueue_script( $this->plugin_name . '-new-jq', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/jquery/jquery-2.1.1.min.js', array(), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-emoji-conf-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/config.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-emoji-util-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/util.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-emoji-area-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/jquery.emojiarea.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-emoji-picker-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/emoji-picker.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-custom-shortcode-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/wanotif-woocommerce-custom-shortcode-admin-min.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );

		wp_localize_script(
			$this->plugin_name . '-custom-shortcode-js',
			'cshortdata',
			array(
				'url_asset'         => WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/',
				'ajax_url'            => admin_url( 'admin-ajax.php' ),
				'ajax_loadData'      => wp_create_nonce( 'wanotif_load_data' ),
				'ajax_saveData'      => wp_create_nonce( 'wanotif_save_data' ),
				'ajax_updateData'      => wp_create_nonce( 'wanotif_update_data' ),
				'ajax_deleteData'    => wp_create_nonce( 'wanotif_delete_data' ),
				'ajax_getSingleData' => wp_create_nonce( 'wanotif_load_single_data' ),
			)
		);
	}

	/**
	 * Ajax load the data.
	 *
	 * @since 0.4.0
	 */
	public function load_data() {
		wp_verify_nonce( 'wanotif_load_data', 'secure_key' );

		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();

		$get_data = $table->show_all();

		echo wp_json_encode( $get_data );

		wp_die();
	}

	/**
	 * Ajax save the data.
	 *
	 * @since 0.4.0
	 */
	public function save_data() {
		wp_verify_nonce( 'wanotif_save_data', 'secure_key' );
		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();
		$data = $_POST['data'];

		// Verify if the data duplicate.
		$is_double = $table->find_by_slug( $data['slug'] );
		if ( ! empty( $is_double ) ) {

			echo 'duplicate';

			wp_die();
			return;
		}

		// Insert the data.
		$save = $table->insert_shortcode( $data );

		if ( $save ) {
			echo 'saved';
		}

		wp_die();
	}

	/**
	 * Ajax edit the data.
	 *
	 * @since 0.4.0
	 */
	public function edit_data() {
		wp_verify_nonce( 'wanotif_update_data', 'secure_key' );
		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();

		$data = $_POST['data'];

		$the_id = $data['id'];

		unset( $data['id'] );

		$action = $table->update_shortcode( $the_id, $data );

		if ( $action ) {
			echo 'updated';
		} else {
			echo 'not work';
		}

		wp_die();
	}

	/**
	 * Ajax delete the data.
	 *
	 * @since 0.4.0
	 */
	public function delete_data() {
		wp_verify_nonce( 'wanotif_delete_data', 'secure_key' );

		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();
		$id = $_POST['data']['shortcode_id'];

		$do_delete = $table->delete_shortcode( $id );

		if ( $do_delete ) {
			echo 'not work';
		} else {
			echo 'deleted';
		}

		wp_die();
	}

	/**
	 * Ajax get single data.
	 *
	 * @since 0.4.0
	 */
	public function get_single_data() {
		wp_verify_nonce( 'wanotif_load_single_data', 'secure_key' );

		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();
		$the_id = $_POST['data']['shortcode_id'];
		$get_data = $table->get_data_by_id( $the_id );

		echo wp_json_encode( $get_data );
		wp_die();
	}
}
