<?php
/**
 * This file responsible to all the action on admin custom log.
 *
 * @link       https://www.linkedin.com/in/arissetia/
 * @since      1.0.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 */

/**
 * Setup admin custom log.
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     M Aris Setiawan <https://www.linkedin.com/in/arissetia/>
 */
class Wanotif_Woocommerce_Admin_Log {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;


	/**
	 * Initialize all required perform.
	 *
	 * @since 1.0.0
	 * @param string $plugin_name The name of this plugin.
	 * @param string $version The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Add menu shortcode
	 *
	 * @since 1.0.0
	 */
	public function register_the_menu() {
		$page_title = 'Wanotif Log';
		$menu_title = 'Wanotif Log';
		$capability = 'manage_options';
		$menu_slug = $this->plugin_name . '_log';
		$function = array( $this, 'display_admin_page' );
		$icon_url = '';
		$position = null;

		add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );
	}

	/**
	 * Display the admin custom shortcode
	 *
	 * @since 1.0.0
	 */
	public function display_admin_page() {
		include_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'admin/partials/wanotif-woocommerce-admin-log.php';
	}

	/**
	 * Register the style and scripts.
	 *
	 * @since 1.0.0
	 * @param string $hook the url location of current admin page.
	 */
	public function register_script_style( $hook ) {
		if ( 'toplevel_page_wanotif-woocommerce_log' !== $hook ) {
			return;
		}
		wp_enqueue_style( $this->plugin_name . '-log-css', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/css/admin-log.css', array(), $this->version, 'all' );
		wp_enqueue_script( $this->plugin_name . '-new-jq', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/jquery/jquery-2.1.1.min.js', array(), $this->version, true );
		wp_enqueue_script( $this->plugin_name . '-log-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/wanotif-woocommerce-log-admin-min.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );

		wp_localize_script(
			$this->plugin_name . '-log-js',
			'WanotifLog',
			array(
				'ajax_url'            => admin_url( 'admin-ajax.php' ),
				'ajax_loadData'      => wp_create_nonce( 'wanotif_load_log_data' ),
			)
		);
	}

	/**
	 * Ajax load the data.
	 *
	 * @since 1.0.0
	 */
	public function load_data() {
		wp_verify_nonce( 'wanotif_load_log_data', 'secure_key' );

		$table = new Wanotif_Woocommerce_Table_Log();

		$get_data = $table->show_all();

		echo wp_json_encode( $get_data );

		wp_die();
	}
}
