<?php
/**
 * This class responsible to all WA setup setting.
 *
 * @link       https://wanotif.id
 * @since      0.2.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 */

/**
 * Setup WA classes action.
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     Wanotif <https://wanotif.id>
 */
class Wanotif_Woocommerce_Admin_Setting_Wa {

	/**
	 * The ID of this plugin.
	 *
	 * @since    0.2.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    0.2.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize all required perform.
	 *
	 * @since 0.2.0
	 * @param string $plugin_name The name of this plugin.
	 * @param string $version The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Add new menu under setting.
	 *
	 * @since 0.2.0
	 */
	public function add_wa_menu_setting() {
		$page_title = 'Wanotif Woo';
		$menu_title = 'Wanotif Woo';
		$capability = 'manage_options';
		$menu_slug = $this->plugin_name . '-wa-auto-setting';
		$function = array( $this, 'display_wa_menu_form' );
		add_options_page( $page_title, $menu_title, $capability, $menu_slug, $function );
	}

	/**
	 * Show WA Form
	 *
	 * @since 0.2.0
	 */
	public function display_wa_menu_form() {
		include_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'admin/partials/wanotif-woocommerce-admin-setting-wa.php';
	}

	/**
	 * Setup Section for form.
	 *
	 * @since 0.2.0
	 */
	public function register_setup_section() {
		$id = 'wa-setting-section';
		// $title = 'setup setting WA';
		$title = '<br>';
		$callback = array();
		$page = 'wa-setting-section';
		add_settings_section( $id, $title, $callback, $page );
	}

	/**
	 * Register field for admin wa setting.
	 *
	 * @since 0.2.0
	 */
	public function setup_fields_wa_setting() {
		$fields = array(
			array(
				'label' => 'Activate Wanotif',
				'id' => $this->plugin_name . '_wanotif_active',
				'class' => '',
				'type' => 'dropdown',
				'section' => 'wa-setting-section',
				'desc' => __( 'Select if wanotif need to active or not', 'wanotif-wocommerce' ),
				'key' => array(
					'off' => 'Off',
					'on' => 'On',
				),
			),
			array(
				'label' => 'Wanotif API Key',
				'id' => $this->plugin_name . '_device-apikey',
				'class' => '',
				'type' => 'text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input this apikey to use wanotif', 'wanotif-wocommerce' ),
				'placeholder' => __( 'Input the api key', 'wanotif-wocommerce' ),
			),
			array(
				'label' => 'Pending Message',
				'id' => $this->plugin_name . '_wa-message-pending',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input the notification for pending', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'On-hold Message',
				'id' => $this->plugin_name . '_wa-message-on-hold',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input the notification for on-hold order', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'Processing Message',
				'id' => $this->plugin_name . '_wa-message-processing',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input the notification for processing (when user pay the invoice)', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'Completed Message',
				'id' => $this->plugin_name . '_wa-message-completed',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input the notification for completed (After the buyer send the payment and seller proces it)', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'Refunded Message',
				'id' => $this->plugin_name . '_wa-message-refunded',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'It\'s when there are refound action ', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'Cancelled Message',
				'id' => $this->plugin_name . '_wa-message-cancelled',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'When the order canceled by system or admin', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
			array(
				'label' => 'Active Reminder',
				'id' => $this->plugin_name . '_wanotif_reminder_active',
				'class' => 'active-reminder',
				'type' => 'dropdown',
				'section' => 'wa-setting-section',
				'desc' => __( 'Select if wanotif need to remind the buyer', 'wanotif-wocommerce' ),
				'key' => array(
					'off' => 'Off',
					'on' => 'On',
				),
			),
			array(
				'label' => 'sent the reminder after buy',
				'id' => $this->plugin_name . '_wanotif_reminder_daytosend',
				'class' => '',
				'type' => 'text',
				'section' => 'wa-setting-section',
				'desc' => __( 'how many days before we can send the buyer? (1,2,3, etc)', 'wanotif-wocommerce' ),
				'placeholder' => __( 'Input the days', 'wanotif-wocommerce' ),
			),
			array(
				'label' => 'Reminder Message',
				'id' => $this->plugin_name . '_wa-message-reminder',
				'class' => '',
				'type' => 'wa-text',
				'section' => 'wa-setting-section',
				'desc' => __( 'Input the notification for reminder', 'wanotif-wocommerce' ),
				'placeholder' => '',
			),
		);

		foreach ( $fields as $field ) {
			$id = $field['id'];
			$title = $field['label'];
			$callback = array( $this, 'field_render_callback' );
			$page = 'wa-setting-section';
			$section = $field['section'];
			$args = $field;
			add_settings_field( $id, $title, $callback, $page, $section, $args );
			register_setting( $section, $field['id'] );
		}
	}

	/**
	 * Render the option field.
	 *
	 * @since 0.2.0
	 *
	 * @param array $field get the data from argument field.
	 */
	public function field_render_callback( $field ) {
		$value = get_option( $field['id'] );
		switch ( $field['type'] ) {

			case 'text':
				echo '<fieldset>';
				printf(
					'<input name="%1$s" id="%1$s" class="%2$s" placeholder="%3$s" value="%4$s">',
					esc_attr( $field['id'] ),
					esc_attr( $field['class'] ),
					esc_attr( $field['placeholder'] ),
					esc_attr( $value )
				);
				echo '<br><label>' . esc_html( $field['desc'] ) . '</label>';
				echo '</fieldset>';
				break;

			case 'wa-text':
				echo '<div class="form-wa-followup">';
				echo '<div class="lead emoji-picker-container">';
				printf(
					'<ul class="toolbar-emoji-text-formater" target-data="%1$s">',
					esc_attr( $field['id'] )
				);
				echo '<li> <a href="" data-action=\'["bold",false,null]\' title="Bold"  style=\'font-weight:bold\'>B</a></li> <li> <a href="" data-action=\'["italic",false,null]\' title="Italic" style=\'font-style: italic\'>I</a></li><li> <a href="" data-action=\'["strikeThrough",false,null]\' title="strike" style="text-decoration: line-through;">Strike</a></li>';
				echo '</ul>';
				printf(
					'<div id="%1$s" name="%1$s" class="%1$s" contenteditable="true" data-emojiable="true" data-emoji-input="unicode">%2$s</div>',
					esc_attr( $field['id'] ),
					esc_html( $value )
				);
				echo '</div>';
				echo '</div>';
				break;

			case 'dropdown':
				echo '<fieldset>';
				printf(
					'<select id="%1$s" name="%1$s" class="%1$s">',
					esc_attr( $field['id'] )
				);

				foreach ( $field['key'] as $key => $val ) {
					$is_selected = '';
					if ( $value === $key ) {
						$is_selected = 'selected';
					}
					printf(
						'<option value="%1$s" %2$s >%3$s</option>',
						esc_attr( $key ),
						esc_attr( $is_selected ),
						esc_attr( $val )
					);
				}
				echo '</select>';
				echo '</fieldset>';
				break;

			default:
				break;
		}
	}

	/**
	 * Register and use script & css
	 *
	 * @since 0.2.0
	 * @param string $hook the url location of current admin page.
	 */
	public function register_script_style( $hook ) {

		if ( 'settings_page_wanotif-woocommerce-wa-auto-setting' === $hook ) {
			wp_register_style( $this->plugin_name . '-wa-admin-css', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/css/wa-admin.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . '-emoji-css', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/css/emoji.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . '-font-aws-css', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->plugin_name . '-wa-admin-css' );



			wp_enqueue_script( $this->plugin_name . '-new-jq', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/jquery/jquery-2.1.1.min.js', array(), $this->version, true );
			wp_enqueue_script( $this->plugin_name . '-emoji-conf-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/config.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
			wp_enqueue_script( $this->plugin_name . '-emoji-util-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/util.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
			wp_enqueue_script( $this->plugin_name . '-emoji-area-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/jquery.emojiarea.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
			wp_enqueue_script( $this->plugin_name . '-emoji-picker-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/js/emoji-picker.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );
			wp_enqueue_script( $this->plugin_name . '-wa-admin-js', WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/wanotif-woocommerce-wa-admin-min.js', array( $this->plugin_name . '-new-jq' ), $this->version, true );

			wp_localize_script(
				$this->plugin_name . '-wa-admin-js',
				'waapi',
				array(
					'url_asset' => WANOTIF_WOOCOMMERCE_PLUGIN_URL . 'admin/js/lib/emoji-picker/',
				)
			);
		}
	}
}
