<?php
/**
 * This file responsible for all the message that send via wanotif.
 *
 * @link       https://wanotif.id
 * @since      0.2.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears/
 */

/**
 * All the action from wassenger will be perform here.
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     Wanotif <wanotif.official@gmail.com>
 */
class Wanotif_WooCommerce_Api {

	/**
	 * This variable to get the api key.
	 *
	 * @var string $apikey the api.
	 */
	private $apikey;

	/**
	 * This variable to set the api url.
	 *
	 * @var string $url the site.
	 */
	private $url;

	/**
	 * This Will consturct and send the data.
	 *
	 * @since 0.2.0
	 * @param string $phone_number the phone number.
	 * @param string $message the message to send.
	 */
	public function __construct() {
		$this->apikey = get_option( 'wanotif-woocommerce_device-apikey', true );
		$this->url = 'https://api.wanotif.id/v1/send';
	}

	/**
	 * Change the standard region into international standard
	 *
	 * The wassanger require (+) so we can peform send a massage
	 *
	 * @since 0.2.0
	 * @param string $phone_number the phone number.
	 */
	public function change_number_internationalize( $phone_number ) {

		if ( preg_match( '/\+/', $phone_number ) ) {
			$phone_number = str_replace( '+', '', $phone_number );
		}

		if ( preg_match( '/^0/', $phone_number ) ) {
			$phone_number = '62' . substr( $phone_number, 1 );
		}

		return $phone_number;
	}

	/**
	 * The action to send the massage
	 *
	 * @since 0.2.0
	 * @param string $phonenumber the target WA number.
	 * @param string $message the message to send.
	 */
	public function send_wa( $phonenumber, $message ) {

		if ( false === $this->apikey ) {
			return 'Please Check the apikey';
		}

		if ( empty( $phonenumber ) ) {
			return 'Please check the phone number';
		}

		$phonenumber = $this->change_number_internationalize( $phonenumber );

		$curl = curl_init();

		curl_setopt_array(
			$curl,
			array(
				CURLOPT_URL => $this->url,
				CURLOPT_HEADER => 0,
				CURLOPT_ENCODING => true,
				CURLOPT_RETURNTRANSFER => 1,
				CURLOPT_SSL_VERIFYHOST => 2,
				CURLOPT_SSL_VERIFYPEER => 0,
				CURLOPT_TIMEOUT => 30,
				CURLOPT_POST => 1,
				CURLOPT_POSTFIELDS =>
				array(
					'Apikey'    => $this->apikey,
					'Phone'     => $phonenumber,
					'Message'   => $message,
				),
			)
		);
		$response = curl_exec( $curl );
		$err = curl_error( $curl );
		curl_close( $curl );

		return $response;
	}
}
