<?php
/**
 * This file is contain class to generate all the custom shortcode.
 *
 * @link       https://wanotif.id
 * @since      0.3.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears/
 */

/**
 * This class is responsible for all the wanotif shortcode .
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     Wanotif <wanotif.official@gmail.com>
 */
class Wanotif_WooCommerce_Shortcode {

	/**
	 * Initialize all the required perform
	 *
	 * @since    0.3.0
	 */
	public function __construct() {

	}

	/**
	 * Responsible to generate all the shortcode
	 *
	 * @since 0.3.0
	 * @param  string  $text the text to process.
	 * @param  integer $post_id the id of post, some of function need this.
	 */
	public function process_message_shortcode( $text, $post_id = '' ) {

		// WooCommerce shortcode process.
		$text = $this->woocommerce_extract_shortcode( $text, $post_id );

		return $text;
	}

	/**
	 * Perform a WooCommerce shortcode.
	 *
	 * @since 0.3.0
	 * @param  string  $text the text to process.
	 * @param  integer $post_id the id of post, some of function need this.
	 */
	private function woocommerce_extract_shortcode( $text, $post_id ) {
		$prefix = 'wanotif_';

		global $woocommerce;
		$order = new WC_Order( $post_id );

		if ( preg_match( '/\[(.*?)\]/', $text ) ) {

			$text = str_replace( "[{$prefix}order_id]", $order->get_order_number(), $text );

			$text = str_replace( "[{$prefix}email]", $order->get_billing_email(), $text );

			$text = str_replace( "[{$prefix}phone]", $order->get_billing_phone(), $text );

			$text = str_replace( "[{$prefix}customer_name]", $order->get_billing_first_name(), $text );

			$text = preg_replace_callback(
				'/\[(' . $prefix . 'total)\]/',
				function () use ( $order ) {
					$total = (int) $order->get_total();
					$total = 'Rp.' . number_format( $total, 0, ',', '.' );
					return $total;
				},
				$text
			);

			$text = preg_replace_callback(
				'/\[(' . $prefix . 'transferto)\]/',
				function () use ( $order, $post_id ) {
					return $this->payment_method_detail( $order, $post_id );
				},
				$text
			);

			$text = preg_replace_callback(
				'/\[(' . $prefix . 'sku)\]/',
				function () use ( $order ) {
					return $this->product_sku_list( $order );
				},
				$text
			);

		}
		return $text;
	}

	/**
	 * Show The payment method.
	 *
	 * @since 0.3.0
	 * @param  object  $order the class of wc_order to get all the data needed.
	 * @param  integer $post_id the id of post, some of function need this.
	 */
	private function payment_method_detail( $order, $post_id ) {
		$order_id = $order->get_order_number();
		$payment_method = $order->get_payment_method();
		$result = '';
		switch ( $payment_method ) {
			case 'bacs':
				$result = $this->get_the_bacs_bank_list( $order_id );
				break;

			default:
				$result = __( 'We can\'t see the payment method or we don\t support that payment method. Please contact us', 'Wanotif-woocommerce' );
				break;
		}
		return $result;
	}

	/**
	 * Show all the list of bacs bank account detail.
	 *
	 * @since 0.3.0
	 * @param integer $order_id the if of order.
	 */
	private function get_the_bacs_bank_list( $order_id ) {
		global $woocommerce;
		$account = '';
		$banks = get_option( 'woocommerce_bacs_accounts' );

		foreach ( $banks as $bank ) {
			$account .= $bank['bank_name'] . ' - AN: ' . $bank['account_name'] . ' - NOREK: ' . $bank['account_number'];
		}

		return $account;
	}
	/**
	 * Show all the SKU product.
	 *
	 * @since 0.3.0
	 * @param object $order Order from WooCommerce.
	 */
	public function product_sku_list( $order ) {
		$sku_list = '';
		$items = $order->get_items();
		$length_array = count( $items );
		$counting = 0;
		foreach ( $items as $item_key => $item ) {
			$counting++;
			$product = $order->get_product_from_item( $item );
			$sku = $product->get_sku();
			$sku_list .= $sku;

			if ( $counting < $length_array ) {
				$sku_list .= ',';
			}
		}

		return $sku_list;
	}

	/**
	 * Register shortcode publicly on WordPress.
	 *
	 * @since 0.4.0
	 */
	public function register_shortcode() {
		add_shortcode( 'wanotif', array( $this, 'render_cutom_shortcode' ) );
	}

	/**
	 * Render the [wanotif] shortcode.
	 *
	 * @since 0.4.0
	 * @param array $atts the attribut of shortcode.
	 */
	public function render_cutom_shortcode( $atts ) {
		$atts = shortcode_atts(
			array(
				'slug' => '',
			),
			$atts,
			'wanotif'
		);
		if ( empty( $atts['slug'] ) ) {
			return '';
		}
		$table = new Wanotif_Woocommerce_Table_Custom_Shortcode();
		$get_data = $table->find_by_slug( $atts['slug'] );

		return $get_data->message;
	}
}
