<?php
/**
 * This file is responsible for custom table custom shortcode
 *
 * @link       https://wanotif.id
 * @since      0.4.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears/
 */

/**
 * This class is responsible for all the custom table custom shortcode.
 *
 * @since      0.4.0
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     Wanotif <wanotif.official@gmail.com>
 */
class Wanotif_Woocommerce_Table_Custom_Shortcode extends Wanotif_Woocommerce_Table_Api {

	/**
	 * Perform all the required after starting.
	 *
	 * @since 0.4.0
	 */
	public function __construct() {
		global $wpdb;

		$this->table_name = $wpdb->prefix . 'wanotif_shortcode';
		$this->primary_key = 'shortcode_id';
	}

	/**
	 * Set the column.
	 *
	 * @since 0.4.0
	 */
	public function get_columns() {
		return array(
			'shortcode_id' => '%d',
			'slug'        => '%s',
			'message'       => '%s',
			'description'   => '%s',
			'date_created'  => '%s',
		);
	}
	/**
	 * Get the default data when empty.
	 *
	 * @since 0.4.0
	 */
	public function get_column_defaults() {
		return array(
			'shortcode_id' => 0,
			'slug'        => '',
			'message'       => '',
			'description'   => '',
			'date_created'  => date( 'Y-m-d H:i:s' ),
		);
	}

	/**
	 * Insert the data.
	 *
	 * @since 0.4.0
	 * @param array $data The data to insert.
	 */
	public function insert_shortcode( $data ) {
		return $this->insert( $data );
	}

	/**
	 * Find by slug.
	 *
	 * @since 0.4.0
	 * @param string $slug find the similiar slug.
	 */
	public function find_by_slug( $slug ) {
		return $this->get_by( 'slug', $slug );
	}

	/**
	 * Get The data by ID.
	 *
	 * @since 0.4.0
	 * @param integer $id the id to search.
	 */
	public function get_data_by_id( $id ) {
		return $this->get( $id );
	}

	/**
	 * Update the data member.
	 *
	 * @since 0.4.0
	 * @param integer $id the id of primary key.
	 * @param array   $data The data to insert.
	 */
	public function update_shortcode( $id, $data ) {
		return $this->update( $id, $data );
	}

	/**
	 * Delete the data of member.
	 *
	 * @since 0.4.0
	 * @param integer $id the id of primary key.
	 */
	public function delete_shortcode( $id ) {
		$this->delete( $id );
	}

	/**
	 * Get All the data.
	 *
	 * @since 0.4.0
	 */
	public function show_all() {
		global $wpdb;

		return $wpdb->get_results(
			$wpdb->prepare(
				'SELECT * FROM %1s ORDER BY date_created DESC',
				$this->table_name
			)
		);
	}

	/**
	 * Create custom table.
	 *
	 * @since 0.4.0
	 */
	public function create_table() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();
		require_once ABSPATH . 'wp-admin/includes/upgrade.php';

		$sql = "CREATE TABLE $this->table_name (
			shortcode_id INTEGER NOT NULL AUTO_INCREMENT,
			slug VARCHAR(30),
			message TEXT,
			description TEXT,
			date_created DATETIME,
			PRIMARY KEY (shortcode_id)
		) $charset_collate;";
		dbDelta( $sql );
	}
}
