<?php
/**
 * This file is responsible for custom table custom shortcode
 *
 * @link       https://wanotif.id
 * @since      0.5.0
 *
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears/
 */

/**
 * This class is responsible for all the custom table custom shortcode.
 *
 * @since      0.5.0
 * @package    Wanotif_Woocommerce
 * @subpackage Wanotif_Woocommerce/includes/gears
 * @author     Wanotif <wanotif.official@gmail.com>
 */
class Wanotif_Woocommerce_Table_Log extends Wanotif_Woocommerce_Table_Api {

	/**
	 * Perform all the required after starting.
	 *
	 * @since 0.5.0
	 */
	public function __construct() {
		global $wpdb;

		$this->table_name = $wpdb->prefix . 'wanotif_log';
		$this->primary_key = 'log_id';
	}

	/**
	 * Set the column.
	 *
	 * @since 0.5.0
	 */
	public function get_columns() {
		return array(
			'log_id'           => '%d',
			'log_post_id'      => '%d',
			'log_status'       => '%d',
			'log_reason'       => '%s',
			'log_phone_number' => '%s',
			'log_message'      => '%s',
			'log_error_code'   => '%s',
			'log_already_send_again' => '%d',
			'date_created'     => '%s',
		);
	}
	/**
	 * Get the default data when empty.
	 *
	 * @since 0.5.0
	 */
	public function get_column_defaults() {
		return array(
			'log_id'           => 0,
			'log_post_id'      => 0,
			'log_status'       => false,
			'log_reason'       => '',
			'log_phone_number' => '',
			'log_message'      => '',
			'log_error_code'   => '',
			'log_already_send_again' => false,
			'date_created'  => date( 'Y-m-d H:i:s' ),
		);
	}

	/**
	 * Insert the data.
	 *
	 * @since 0.5.0
	 * @param array $data The data to insert.
	 */
	public function insert_log( $data ) {
		return $this->insert( $data );
	}

	/**
	 * Get The data by ID.
	 *
	 * @since 0.5.0
	 * @param integer $id the id to search.
	 */
	public function get_data_by_id( $id ) {
		return $this->get( $id );
	}

	/**
	 * Update the log.
	 *
	 * @since 0.5.0
	 * @param integer $id the id of primary key.
	 * @param array   $data The data to insert.
	 */
	public function update_log( $id, $data ) {
		return $this->update( $id, $data );
	}

	/**
	 * Delete the log.
	 *
	 * @since 0.5.0
	 * @param integer $id the id of primary key.
	 */
	public function delete_log( $id ) {
		$this->delete( $id );
	}

	/**
	 * Get All the data.
	 *
	 * @since 0.5.0
	 */
	public function show_all() {
		global $wpdb;

		return $wpdb->get_results(
			$wpdb->prepare(
				'SELECT * FROM %1s ORDER BY date_created DESC',
				$this->table_name
			)
		);
	}

	/**
	 * Create custom table.
	 *
	 * @since 0.5.0
	 */
	public function create_table() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();
		require_once ABSPATH . 'wp-admin/includes/upgrade.php';

		$sql = "CREATE TABLE $this->table_name (
			log_id INTEGER NOT NULL AUTO_INCREMENT,
			log_post_id INTEGER,
			log_status BOOLEAN,
			log_reason VARCHAR(150),
			log_phone_number VARCHAR(25),
			log_message TEXT,
			log_error_code VARCHAR(50),
			log_already_send_again BOOLEAN,
			date_created DATETIME,
			PRIMARY KEY (log_id)
		) $charset_collate;";
		dbDelta( $sql );
	}
}
