<?php
/**
 * The plugin bootstrap file
 *
 * @link              https://www.linkedin.com/in/arissetia/
 * @since             0.1.0
 * @package           wanotif_woocommerce
 *
 * @wordpress-plugin
 * Plugin Name:       Wanotif WooCommerce
 * Plugin URI:        https://gitlab.com/wanotif/wanotif-woocommerce
 * Description:       wanotif integration with WooCommerce.
 * Version:           1.0.1
 * Author:            M Aris Setiawan
 * Author URI:        https://www.linkedin.com/in/arissetia/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wanotif-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


define( 'WANOTIF_WOOCOMMERCE_VERSION', '1.0.1' );

// Plugin Folder Path.
if ( ! defined( 'WANOTIF_WOOCOMMERCE_PLUGIN_DIR' ) ) {
	define( 'WANOTIF_WOOCOMMERCE_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
}
// Plugin Folder URL.
if ( ! defined( 'WANOTIF_WOOCOMMERCE_PLUGIN_URL' ) ) {
	define( 'WANOTIF_WOOCOMMERCE_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
}
// Plugin directory name only.
if ( ! defined( 'WANOTIF_WOOCOMMERCE_PLUGIN_DIR_NAME' ) ) {
	define( 'WANOTIF_WOOCOMMERCE_PLUGIN_DIR_NAME', basename( __DIR__ ) );
}
// Plugin Root File.
if ( ! defined( 'WANOTIF_WOOCOMMERCE_PLUGIN_FILE' ) ) {
	define( 'WANOTIF_WOOCOMMERCE_PLUGIN_FILE', __FILE__ );
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wanotif-woocommerce-activator.php
 */
function activate_wanotif_woocommerce() {
	require_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'includes/class-wanotif-woocommerce-activator.php';
	require_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'includes/gears/class-wanotif-woocommerce-table-api.php';
	require_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'includes/gears/class-wanotif-woocommmerce-table-custom-shortcode.php';
	require_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'includes/gears/class-wanotif-woocommmerce-table-log.php';
	Wanotif_Woocommerce_Activator::activate();
	Wanotif_Woocommerce_Activator::create_table_shortcode();
	Wanotif_Woocommerce_Activator::create_table_log();
	Wanotif_Woocommerce_Activator::wanotif_register_reminder_buyer();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wanotif-woocommerce-deactivator.php
 */
function deactivate_wanotif_woocommerce() {
	require_once WANOTIF_WOOCOMMERCE_PLUGIN_DIR . 'includes/class-wanotif-woocommerce-deactivator.php';
	Wanotif_Woocommerce_Deactivator::deactivate();
	Wanotif_Woocommerce_Deactivator::wanotif_unregister_reminder_buyer();
}

register_activation_hook( __FILE__, 'activate_wanotif_woocommerce' );
register_deactivation_hook( __FILE__, 'deactivate_wanotif_woocommerce' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wanotif-woocommerce.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    0.1.0
 */
function run_wanotif_woocommerce() {

	$plugin = new Wanotif_Woocommerce();
	$plugin->run();

}
run_wanotif_woocommerce();
